import { __spread } from 'tslib';
import { retryBackoff } from 'backoff-rxjs';

var isServerError = function (response) { return response.status >= 500; };

var isUnknownError = function (response) { return response.status === 0; };

var or = function () {
    var predicates = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        predicates[_i] = arguments[_i];
    }
    return function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        return predicates.some(function (predicate) { return predicate.apply(void 0, __spread(args)); });
    };
};
var isServerOrUnknownError = function (response) {
    return or(isServerError, isUnknownError)(response);
};

var RetryHandler = /** @class */ (function () {
    function RetryHandler(_a) {
        var initialInterval = _a.initialInterval, maxInterval = _a.maxInterval, maxRetries = _a.maxRetries, shouldRetry = _a.shouldRetry;
        this._initialInterval = initialInterval;
        this._maxInterval = maxInterval;
        this._maxRetries = maxRetries;
        this._shouldRetry = shouldRetry;
    }
    RetryHandler.prototype.handle = function (_a) {
        var request = _a.request, next = _a.next;
        return next({ request: request }).pipe(retryBackoff({
            initialInterval: this._initialInterval,
            maxInterval: this._maxInterval,
            maxRetries: this._maxRetries,
            shouldRetry: this._shouldRetry
        }));
    };
    return RetryHandler;
}());

/**
 * @param condition
 * @param initialInterval defaults to 200ms
 * @param maxInterval defaults to 1min
 * @param maxRetries defaults to 10
 * @param shouldRetry defaults to server error: 5xx
 */
function createRetryPlugin(_a) {
    var _b = _a === void 0 ? {} : _a, _c = _b.condition, condition = _c === void 0 ? function () { return true; } : _c, _d = _b.initialInterval, initialInterval = _d === void 0 ? 200 : _d, _e = _b.maxInterval, maxInterval = _e === void 0 ? 60000 : _e, // 1 min
    _f = _b.maxRetries, // 1 min
    maxRetries = _f === void 0 ? 10 : _f, _g = _b.shouldRetry, shouldRetry = _g === void 0 ? isServerOrUnknownError : _g;
    return {
        condition: condition,
        handler: new RetryHandler({
            initialInterval: initialInterval,
            maxInterval: maxInterval,
            maxRetries: maxRetries,
            shouldRetry: shouldRetry
        })
    };
}

/**
 * Generated bundle index. Do not edit.
 */

export { createRetryPlugin, RetryHandler as ɵa };
//# sourceMappingURL=http-ext-plugin-retry.js.map
